/*
 Author : MEZIERE Fabien
 Project : SRO2001
 Website : https://www.instructables.com/member/-SRO2-/
 Description : This is the source code of my WaterLevelAlarm, for more information or any suggestion go to the website ;)

   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. 1
*/

#include "E:\Projets electronique\WaterLevelAlarm\Programmation\Main.h"

const char StatusLed = PIN_A1;					// This is the pin of LED who it's turn ON when the system requires an intervention of the user
const char AlarmBuzzer = PIN_A2;				// This is the pin where the buzzer is connected
const char BtnCmdAlarm = PIN_A4;				// This is the pin where the command button is connected
const char Detector = PIN_A5;					// This is the pin where the detector of liquid is connected		
void DetectionManagment();						// This function manage the system when a liquid is detected (alarm tone and command button)

#int_RA
RA_isr() 
{
	if(input(Detector)==0)						// If there is a contact on the detector pin (liquid level anormal)
	{
		DetectionManagment();
	}
}

void main()
{
	// Setup PIC configuration	
 	port_a_pullups(0b00000001);
	setup_adc_ports(NO_ANALOGS|VSS_VDD);		
	setup_adc(ADC_OFF);
	setup_timer_0(RTCC_INTERNAL|RTCC_DIV_1);
	setup_timer_1(T1_DISABLED);	
	setup_comparator(NC_NC);
	setup_vref(FALSE);
	enable_interrupts(INT_RA5);					// Active interrupt exception on PIN_A5 in order to detect if a change occured on this pin and wake up the CPU (liquid level detection)
	enable_interrupts(GLOBAL);

	// START of the test phase
	output_high(StatusLed);						// Turns on the status LED
	do											// Wait until user push the command button and checks if the detector is not activated
	{
		delay_ms(50);
	}while(input(BtnCmdAlarm)==0 || input(Detector)==0);
	output_high(AlarmBuzzer);					// Turns on the alarm tone for 3 bips (take approximately 2 seconds)
	delay_ms(1800);
	output_low(StatusLed);						// Turns off the status LED
	output_low(AlarmBuzzer);					// Turns off the alarm tone
	// END of the test phase
	
	while(1)									// Main loop, set the CPU to SLEEP mode
	{
		sleep();
	}
}

void DetectionManagment()
{		
		output_high(AlarmBuzzer);				// Turns on the alarm tone
		do										// Start the alarm tone until user push the command button
		{
			output_high(StatusLed);				// Flickering the status LED every 500ms
			delay_ms(500);
			output_low(StatusLed);				
			delay_ms(500);
		}while(input(BtnCmdAlarm)==0);
		
		output_low(AlarmBuzzer);				// Turns off the alarm tone
		output_high(StatusLed);					// Turns on the status LED to inform the user that the system is on standby
		
		do										// Wait until user release the command button
		{
			delay_ms(50);
		}while(input(BtnCmdAlarm)==1);
			
		do										// Wait until user push again on the command button to rearm the alarm (it's necessary that detector is not activated)
		{
			delay_ms(50);
		}while(input(BtnCmdAlarm)==0 || input(Detector)==0);
		
		output_low(StatusLed);					// Turns off the status LED
}		


